@@ -8,7 +8,7 @@ from contextlib import contextmanager
 from tempfile import TemporaryDirectory
 from unittest import TestCase
 
-from lockable.lockable import Lockable, ResourceNotFound, Allocation, timedelta
+from lockable.lockable import Lockable, ResourceNotFound, Allocation
 
 
 @contextmanager
@@ -165,23 +165,6 @@ class LockableTests(TestCase):
             lockable.unlock(allocation)
             self.assertFalse(os.path.exists(lock_file))
 
-    def test_allocation_object(self):
-        alloc = Allocation(requirements={},
-                           resource_info={'id': 1},
-                           alloc_id=1,
-                           pid_file=1,
-                           _release=lambda: True)
-        self.assertEqual(alloc.resource_id, 1)
-        self.assertIsInstance(alloc.allocation_durations, timedelta)
-        with self.assertRaises(AssertionError):
-            alloc.release(2)
-        alloc.release(1)
-        with self.assertRaises(AssertionError):
-            alloc.unlock()
-        self.assertEqual(alloc.allocation_durations,
-                         alloc.release_time - alloc.allocation_start_time)
-        self.assertEqual(alloc.allocation_queue_time, None)
-
     def test_lock_offline(self):
         with TemporaryDirectory() as tmpdirname:
             list_file = os.path.join(tmpdirname, 'test.json')
